## CKEditor 5 - Tags ♥️
This module integrates directly into CKEditor 5 and allows you to integrate rich semantic tags inside your text contents.

### What could I use it for?
Let's imagine you have a component into a page that should display data from a remote source:
This plugin will let you inject dynamic data into a totally static and "unaware" component, effectively decoupling the data-logic from its representation on its context.

### Where can I use tags?
Everywhere rich text can be placed! The modules comes with a handy JS library for easy data substitution with spinners.
Tags can also be styled as you want ❤️.

### Installation
- Install and Enable CKEditor 5

``composer require 'drupal/ckeditor5_tags'``

``drush en ckeditor_tags``

- Enable the DynamicTags widget in the CKEditor5 configuration (/admin/config/content/formats).
- DONE!

### How do I use it?

- After the installations, contribute any number of dynamicTags through any field that supports rich text.
- Each dynamicTag will require an ID (to be referenced later) and a Label that will contain default text up until substitution (if ever occurs).
- The module will populate an global object containing all the dynamicTags that are available in the current context, with support methods for easy content substitution and spinner support.
- You'll be able to access the context of any created dynamicTag using the global ``window.dynamicTags.tags`` object from any other JS library you have in place**.

**Since tags are initialized with a lazy approach, you won't see any update on the ``dynamicTags`` global until your first read on the ``dynamicTags.tags`` object.

** Another interesting usage of the dynamicTags functionality is to leverage the markup it provides to extend style or add business logic to otherwise completely static chunks of text. ** 

```javascript
/* window context */
dynamicTags: {
    tags: {
        "tag-id": {
            $elem: $elem, //HTMLSpanElement element that contains the dynamic tag structure
            $target: $elem, //HTMLSpanElement element that contains the target value to change
            isReplaced: true, //boolean that tells whether this value has been updated at least once
            isWaiting: false, //boolean that tells whether this tag is waiting for a substitution, and has its spinner visible
            replace: function, //callback - accepts the string value to inject into the DOM
            wait: function, //callback - activates the spinner for this dynamicTag
            stop: function, //callback - stops the spinner for this dynamicTag
            
        }
    }
} 
```

### Source code
<a href="https://www.drupal.org/project/ckeditor5_tags">Drupal Module</a>

### Say Thanks!

If you find this module helpful, and you want to contribute to my work, or allow me to spend more of my free time on this, feel free to show your appreciation!
Even the smallest donation is of great encouragment and is much appreciated!

<a href="https://buymeacoffee.com/devicious.dev"><img src="https://www.drupal.org/files/project-images/buymeacoffee.png" /></a>